@@ -189,13 +189,6 @@ eafdiffplot <-
     data_right <- transform_maximise(data_right, maximise)
   }
 
-  compute_attsurfs <- function(x, cumsizes, percentiles, maximise) {
-    x <- compute_eaf_call(x, cumsizes = cumsizes, percentiles = percentiles)
-    if (any(maximise))
-      x[,-ncol(x)] <- transform_maximise(x[, -ncol(x), drop=FALSE], maximise)
-    eaf_as_list(x)
-  }
-
   attsurfs_left <- attsurfs_right <- list()
   if (!any(is.na(percentiles))) {
     attsurfs_left <- compute_attsurfs(data_left, cumsizes_left, percentiles = percentiles, maximise = maximise)
@@ -262,7 +255,7 @@ eafdiffplot <-
 
   # FIXME: This does not generate empty space between the two plots, but the
   # plots are not squared.
-  layout(matrix(1:2, ncol=2L, byrow=TRUE), respect=TRUE)
+  layout(matrix(c(1L,2L), ncol=2L, byrow=TRUE), respect=TRUE)
   bottommar <- 5L
   topmar   <- 4L
   leftmar  <- 4L
@@ -363,8 +356,6 @@ plot_eafdiff_side <- function (eafdiff, attsurfs = list(),
 
            # Colors are correct for !full.eaf && type == "area"
            if (full.eaf || type == "point") {
-             diff_values <- eafdiff[,3L]
-             eafdiff <- eafdiff[, 1L:2L, drop=FALSE]
              # FIXME: This is wrong, we should color (0.0, 1] with col[1], then (1, 2]
              # with col[1], etc, so that we never color the value 0.0 but we always
              # color the maximum value color without having to force it.
@@ -372,10 +363,12 @@ plot_eafdiff_side <- function (eafdiff, attsurfs = list(),
              # Why flooring and not ceiling? If a point has value 2.05, it should
              # be painted with color 2 rather than 3.
              # +1 because col[1] is white ([0,1)).
-             diff_values <- floor(diff_values) + 1
+             diff_values <- floor(eafdiff[,3L]) + 1
              if (nunique(diff_values) > length(col)) {
-               stop ("Too few colors: length(unique(diff_values)) > length(col)")
+               stop ("Too few colors: there are ", nunique(diff_values),
+                 " unique values but only ", length(col), " colors")
              }
+             eafdiff <- eafdiff[, c(1L,2L), drop=FALSE]
            }
            if (type == "area") {
              if (full.eaf) {
@@ -406,6 +399,7 @@ plot_eafdiff_side <- function (eafdiff, attsurfs = list(),
              ## The maximum value should also be painted.
              diff_values[diff_values > length(col)] <- length(col)
              eafdiff <- eafdiff[order(diff_values, decreasing = FALSE), , drop=FALSE]
+             diff_values <- diff_values[order(diff_values, decreasing = FALSE)]
              points(eafdiff[,1L], eafdiff[,2L], col = col[diff_values], type = "p", pch=20)
            }
          }
@@ -419,3 +413,11 @@ plot_eafdiff_side <- function (eafdiff, attsurfs = list(),
   mtext(title, 1, line = 3.5, cex = par("cex.lab"), las = 0, font = 2)
   box()
 }
+
+compute_attsurfs <- function(x, cumsizes, percentiles, maximise)
+{
+  x <- compute_eaf_call(x, cumsizes = cumsizes, percentiles = percentiles)
+  if (any(maximise))
+    x[,-ncol(x)] <- transform_maximise(x[, -ncol(x), drop=FALSE], maximise)
+  eaf_as_list(x)
+}
